#!/usr/bin/env jython
# .+
# .context    : Application View Controller
# .title      : tree widget display capabilities (Swing),
#		GUI programmatically generated
# .kind	      : python source
# .author     : Fabrizio Pollastri
# .site	      : Torino - Italy
# .creation   :	6-Nov-2009
# .copyright  : (c) 2009 Fabrizio Pollastri.
# .license    : GNU General Public License (see below)
#
# This file is part of "AVC, Application View Controller".
#
# AVC is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# AVC is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# .-

from javax import swing			# swing toolkit bindings
from java import awt			# awt toolkit bindings

from avc import *			# AVC for Swing

import copy				# object cloning support


class Example(AVC):
  """
  Showcase of display capabilities for the tree view widget
  """

  def __init__(self):

    # create GUI
    root = swing.JFrame('AVC Swing tree example',size=(800,220),
      defaultCloseOperation = swing.JFrame.EXIT_ON_CLOSE)
    root.layout = awt.FlowLayout()
    root.add(swing.JLabel(name='tree__label',))
    self.jtree = swing.JTree(name='tree__table')
    self.jtree.setEditable(True)
    scrollpane = swing.JScrollPane()
    scrollpane.setPreferredSize(awt.Dimension(200,160))
    scrollpane.getViewport().setView(self.jtree)
    root.add(scrollpane)
    root.show()

    # connected variables
    self.tree = {'body':{ \
      # root rows
      '1':'one', \
      '2':'two', \
      # children of root row '1'
      '1.1':'one one', \
      '1.2':'one two', \
      # children of root row '2'
      '2.1':'two one', \
      '2.2':'two two'}}


#### MAIN

example = Example()			# instantiate the application
example.avc_init()			# connect widgets with variables

# expand first level rows in the tree
for i in range(example.jtree.getRowCount()):
  example.jtree.expandRow(i)

#### END



#!/usr/bin/python
# .+
#
# .context    : Application View Controller
# .title      : AVC distutils setup
# .kind	      : python source
# .author     : Fabrizio Pollastri <pollastri@iriti.cnr.it>
# .site	      : Torino - Italy
# .creation   :	11-Nov-2006
# .copyright  :	(c) 2006-2009 Fabrizio Pollastri
# .license    : GNU General Public License (see below)
#
# This file is part of "AVC, Application View Controller".
#
# AVC is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# AVC is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# .-

from distutils.core import setup
from shutil import copytree, rmtree
import os, os.path
import re
import sys

# parameters
classifiers = """\
Development Status :: 4 - Beta
Intended Audience :: Developers
License :: OSI Approved :: GNU General Public License (GPL)
Programming Language :: Python
Topic :: System :: Hardware
Topic :: Software Development :: Libraries :: Python Modules
Operating System :: POSIX :: Linux
"""

# when command is 'install', we need to differentiate among python or jython
# install, selecting only files required respectively by python or jython.
# When command is 'sdist' there is no difference all files all copied into src.
if sys.argv[1] == 'install':
  # if command is 'install', create a temporary installation dir
  PACKAGE_DIR = {'avc':'src.setup'}
  copytree('src','src.setup')
  # remove files not required respectively by python or jython
  if 'python' in os.path.split(sys.executable)[1]:
    os.remove('src.setup/avcswing.py')
  else:
    map(os.remove,['src.setup/avcgtk.py','src.setup/avcqt3.py',
      'src.setup/avcqt4.py','src.setup/avctk.py','src.setup/avcwx.py'])
else:
  # for all other commands use original src dir
  PACKAGE_DIR = {'avc':'src'}

# workaround older python versions
if sys.version_info < (2, 3):
  _setup = setup
  def setup(**kwargs):
    if kwargs.has_key("classifiers"):
      del kwargs["classifiers"]
    _setup(**kwargs)

# read version string, author name, author e-mail from file
ftext = open('src/avccore.py').read()
VERSION = re.search('__version__\s+=\s+\'(\d+\.\d+\.\d+)\'',ftext).group(1)
AUTHOR = re.search('__author__ = \'([a-zA-Z]+\s+[a-zA-Z]+)\s+',ftext).group(1)
AUTHOR_EMAIL = re.search('__author__ = .*?<(.*?)>',ftext).group(1)

# do setup
setup (
  name = 'avc',
  version = VERSION,
  author = AUTHOR,
  author_email = AUTHOR_EMAIL,
  maintainer = AUTHOR,
  maintainer_email = AUTHOR_EMAIL,
  url = 'http://avc.inrim.it',
  #download_url = 'http://avc.inrim.it/dist/avc-' + VERSION + '.tar.gz',
  license = 'http://www.gnu.org/licenses/gpl.txt',
  platforms = ['Linux'],
  description = """
  AVC, the Application View Controller is a multiplatform, fully transparent,
  automatic and live connector between the values displayed and entered by GUI
  widgets and the variables of an application using the GUI.""",
  classifiers = filter(None, classifiers.split("\n")),
  long_description =  "see html/index.html or http://avc.inrim.it/",
  package_dir = PACKAGE_DIR,
  packages = ['avc'])

# cleanup
if os.access('MANIFEST',os.F_OK):
  os.remove('MANIFEST')
if os.access('src.setup',os.F_OK):
  rmtree('src.setup')

#### END



#!/usr/bin/python
# .+
#
# .identifier :	$Id: example2.py,v 1.1 2006/11/20 17:31:56 fabrizio Exp $
# .context    : Application View Controller
# .title      : A table of all supported widget/control type conbinations (Tk)
# .kind	      : python source
# .author     : Fabrizio Pollastri
# .site	      : Revello - Italy
# .creation   :	19-Nov-2006
# .copyright  : (c) 2006 Fabrizio Pollastri.
# .license    : GNU General Public License (see below)
#
# This file is part of "AVC, Application View Controller".
#
# AVC is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# AVC is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# .-


from Tkinter import * 			# Tk interface

from avc import *			# AVC

INCREMENTER_PERIOD = 0.333		# seconds


class Example(AVC):
  """
  A table of all supported widget/control type conbinations
  """

  def __init__(self):

    ## create GUI
    self.root = Tk()
    self.root.title('AVC Tk showcase example')

    # row 0: titles
    Label(self.root,text='Control Type').grid(row=0)
    Label(self.root,text='Widgets').grid(row=0,column=1,columnspan=3)
    Label(self.root,text='Control Value').grid(row=0,column=4)

    # row 1: button/boolean variable
    Label(self.root,text='boolean').grid(row=1,rowspan=2)
    button1 = Button(self.root,text='button',name='boolean1__button1')
    button1.grid(row=1,column=1,columnspan=3)
    label1 = Label(self.root,text='boolean1',name='boolean1__label1')
    label1.grid(row=1,column=4)
    
    # row 2: checkbutton/boolean variable 
    button2 = Checkbutton(self.root,text='button',name='boolean2__button2')
    button2.grid(row=2,column=1,columnspan=3)
    label2 = Label(self.root,text='boolean2',name='boolean2__label2')
    label2.grid(row=2,column=4)

    # row 3: triple radio button/index variable (integer)
    Label(self.root,text='index').grid(row=3)
    radiobutton0 = Radiobutton(self.root,text='radiobutton0',value=0,
      name='radio__radiobutton0')
    radiobutton1 = Radiobutton(self.root,text='radiobutton1',value=1,
      name='radio__radiobutton1')
    radiobutton2 = Radiobutton(self.root,text='radiobutton2',value=2,
      name='radio__radiobutton2')
    radiobutton0.grid(row=3,column=1)
    radiobutton1.grid(row=3,column=2)
    radiobutton2.grid(row=3,column=3)
    label3 = Label(self.root,text='index',name='radio__label3')
    label3.grid(row=3,column=4)

    # row 4: spin button/text entry/integer variable
    Label(self.root,text='integer').grid(row=4)
    spinbox1 = Spinbox(self.root,name='integer__spinbox1',increment=1,
      to=100)
    spinbox1.grid(row=4,column=1)
    entry1 = Entry(self.root,textvariable=StringVar(),name='integer__entry1')
    entry1.grid(row=4,column=2,columnspan=2)
    label4 = Label(self.root,text='integer',name='integer__label4')
    label4.grid(row=4,column=4)

    # row 5: spin button/text entry/float variable
    Label(self.root,text='float').grid(row=5)
    spinbox2 = Spinbox(self.root,name='float__spinbox2',increment=1.0,
      to=100.0)
    spinbox2.grid(row=5,column=1)
    entry2 = Entry(self.root,textvariable=StringVar(),name='float__entry2')
    entry2.grid(row=5,column=2,columnspan=2)
    label5 = Label(self.root,text='float',name='float__label5')
    label5.grid(row=5,column=4)

    # row 6: entry/string variable
    Label(self.root,text='string').grid(row=6)
    entry3 = Entry(self.root,textvariable=StringVar(),name='string__entry3')
    entry3.grid(row=6,column=1,columnspan=3)
    label6 = Label(self.root,text='string',name='string__label6')
    label6.grid(row=6,column=4)

    # the control variables
    self.boolean1 = False
    self.boolean2 = False
    self.radio = 0
    self.integer = 0
    self.float = 0.0
    self.string = ''

    # start variables incrementer
    increment = self.incrementer()
    self.timer_function = increment.next
    self.root.after(int(INCREMENTER_PERIOD * 1000.0),self.timer_wrap)


  def timer_wrap(self):
    "Call given function, reschedule it after return"
    self.timer_function()
    self.root.after(int(INCREMENTER_PERIOD * 1000.0),self.timer_wrap)


  def incrementer(self):
    """
    Booleans are toggled, radio button index is rotated from first to last,
    integer is incremented by 1, float by 0.5, string is appended a char
    until maxlen when string is cleared. Return True to keep timer alive.
    """
    while True:
      self.boolean1 = not self.boolean1
      yield True

      self.boolean2 = not self.boolean2
      yield True

      if self.radio == 2:
        self.radio = 0
      else:
        self.radio += 1
      yield True

      self.integer += 1
      yield True

      self.float += 0.5
      yield True

      if len(self.string) >= 20:
        self.string = 'A'
      else:
        self.string += 'A'
      yield True


#### MAIN

example = Example()			# instantiate the application
example.avc_init()			# connect widgets with variables
mainloop()				# run Tk event loop until quit

#### END




#!/usr/bin/python
# .+
#
# .identifier :	$Id:$
# .context    : Application View Controller
# .title      : A spin box replicated into a text label (Qt4)
# .kind	      : python source
# .author     : Fabrizio Pollastri
# .site	      : Revello - Italy
# .creation   :	7-Dec-2006
# .copyright  : (c) 2006 Fabrizio Pollastri.
# .license    : GNU General Public License (see below)
#
# This file is part of "AVC, Application View Controller".
#
# AVC is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# AVC is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# .-


from PyQt4.QtCore import *		# Qt core
from PyQt4.QtGui import *		# Qt GUI interface
from PyQt4.uic import *			# ui files realizer
import sys				# system support

from avc import *			# AVC

UI_FILE = 'qt4_spinbox.ui'		# qt ui descriptor


class Example(QApplication,AVC):
  """
  A spin box whose value is replicated into a text label
  """

  def __init__(self):

    # create GUI
    QApplication.__init__(self,sys.argv)
    self.root = loadUi(UI_FILE)
    self.root.show()
    
    # the variable holding the spin box value
    self.spin_value = 0
    

#### MAIN

example = Example()			# instantiate the application
example.avc_init()			# connect widgets with variables
example.exec_()				# run Qt event loop until quit

#### END



#!/usr/bin/python
# .+
#
# .identifier :	$Id:$
# .context    : Application View Controller
# .title      : A random generation of count down windows (wx)
# .kind	      : python source
# .author     : Fabrizio Pollastri
# .site	      : Torino - Italy
# .creation   :	13-May-2008
# .copyright  : (c) 2008 Fabrizio Pollastri.
# .license    : GNU General Public License (see below)
#
# This file is part of "AVC, Application View Controller".
#
# AVC is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# AVC is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# .-


import wx				# wx tool kit bindings
from wx import xrc			# xml resource support

from avc import *			# AVC

from random import randint		# random integer generator

WXGLADE_MAIN = 'wx_countdown_main.xrc'	# main window glade descriptor
WXGLADE_CD = 'wx_countdown.xrc'		# count down window glade descriptor
FIRST_COUNT_DELAY = 1000		# let avc_init be called
COUNTDOWN_PERIOD = 500			# count down at 2 unit per second
MAX_CREATION_PERIOD = 4000		# create a new count down at 1/2 this


class Countdown(AVC):
  """
  A countdown counter displayed in a Label widget. Count starts at given
  value. When count reaches zero the counter and its GUI are destroyed.
  """

  def __init__(self,count_start=10):

    # create GUI
    xml_resource = xrc.XmlResource(WXGLADE_CD)
    self.root = xml_resource.LoadFrame(None,'frame_1')
    self.root.Show()

    # init the counter variable 
    self.counter = count_start

    # connect counter variable with label widget
    self.avc_connect(self.root)

    # start count down
    self.timer = wx.Timer(self.root,wx.NewId())
    self.root.Bind(wx.EVT_TIMER,self.decrementer,self.timer)
    self.timer.Start(COUNTDOWN_PERIOD)


  def decrementer(self,event):
    "Counter decrementer. Return False to destroy previous timer."
    self.counter -= 1
    if not self.counter:
      # counter reached zero: destroy this countdown and its GUI
      self.root.Close()


class Example(wx.PySimpleApp,AVC):
  """
  Continuously create at random intervals windows with a countdown from 10 to 0.
  When a countdown reaches zero, its window is destroyed. Also create a main
  window with a "close all" button.
  """

  def __init__(self):

    # init wx application base class
    wx.PySimpleApp.__init__(self)

    # create GUI
    xml_resource = xrc.XmlResource(WXGLADE_MAIN)
    self.root = xml_resource.LoadFrame(None,'frame_1')
    self.root.Show()

    # terminate application at main window close
    self.root.Bind(wx.EVT_CLOSE,self.on_destroy)

    # close all button connected variable
    self.close_all = False

    # create count down creation timer
    self.timer = wx.Timer(self.root,wx.NewId())
    self.root.Bind(wx.EVT_TIMER,self.new_countdown,self.timer)

    # create the first countdown after avc_init call
    self.timer.Start(FIRST_COUNT_DELAY,oneShot=True)


  def new_countdown(self,event,count_start=10):
    "Create a new countdown"

    # create a new countdown
    Countdown(count_start)

    # autocall after a random delay
    self.timer.Start(randint(1,MAX_CREATION_PERIOD),oneShot=True)


  def on_destroy(self,window):
    "Terminate program at window destroy"
    self.Exit()

  def close_all_changed(self,value):
    "Terminate program at 'close all' button pressing"
    self.Exit()


#### MAIN

example = Example()			# instantiate the application
example.avc_init()			# connect widgets with variables
example.MainLoop()		 	# run wx event loop until quit

#### END



#!/usr/bin/python
# .+
#
# .identifier :	$Id:$
# .context    : Application View Controller
# .title      : A counter with count speed control (wx)
# .kind	      : python source
# .author     : Fabrizio Pollastri
# .site	      : Revello - Italy
# .creation   :	24-Nov-2007
# .copyright  : (c) 2007 Fabrizio Pollastri.
# .license    : GNU General Public License (see below)
#
# This file is part of "AVC, Application View Controller".
#
# AVC is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# AVC is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# .-


import wx				# wx tool kit bindings

from avc import *			# AVC

LOW_SPEED = 500				#--
HIGH_SPEED = 100			#- low and high speed period (ms)


class Example(wx.PySimpleApp,AVC):
  """
  A counter displayed in a static text widget whose count speed can be
  accelerated by checking a check box.
  """

  def __init__(self):

    ## create GUI

    # init wx application base class
    wx.PySimpleApp.__init__(self)

    # create widgets: a top level window, a label and a spin control.
    self.root = wx.Frame(None,title='AVC wx counter example',size=(320,60))
    label = wx.StaticText(self.root,label='%s',name='counter__label',
      size=(100,20))
    checkbox = wx.CheckBox(self.root,label='high speed',
      name='high_speed__checkbox',size=(100,25))

    # layout the label and the check box horizontally into the window
    hsizer = wx.BoxSizer(wx.HORIZONTAL)
    hsizer.Add((20,10),proportion=1)
    hsizer.Add(label,proportion=0.5,flag=wx.CENTER)
    hsizer.Add(checkbox,proportion=0.5,flag=wx.CENTER)
    hsizer.Add((20,10),proportion=1)
    self.root.SetSizer(hsizer)
    self.root.Show()

    ## the counter variable and its speed status
    self.counter = 0
    self.high_speed = False

    # start counter incrementer at low speed
    self.timer = wx.Timer(self.root,wx.NewId())
    self.root.Bind(wx.EVT_TIMER,self.incrementer,self.timer)
    self.timer.Start(LOW_SPEED,oneShot=True)


  def incrementer(self,event):
    """
    Counter incrementer: increment period = LOW_SPEED, if high speed is False,
    increment period = HIGH_SPEED otherwise. Return False to destroy previous
    timer.
    """
    self.counter += 1
    if self.high_speed:
      period = HIGH_SPEED
    else:
      period = LOW_SPEED
    self.timer.Start(period,oneShot=True)

  def high_speed_changed(self,value):
    "Notify change of counting speed to terminal"
    if value:
      print 'counting speed changed to high'
    else:
      print 'counting speed changed to low'


#### MAIN

example = Example()			# instantiate the application
example.avc_init()			# connect widgets with variables
example.MainLoop()		 	# run wx event loop until quit

#### END



#!/usr/bin/python
# .+
#
# .identifier :	$Id:$
# .context    : Application View Controller
# .title      : Color selection widget connected to label widget (GTK)
# .kind	      : python source
# .author     : Fabrizio Pollastri
# .site	      : Torino - Italy
# .creation   :	4-Feb-2013
# .copyright  : (c) 2013 Fabrizio Pollastri.
# .license    : GNU General Public License (see below)
#
# This file is part of "AVC, Application View Controller".
#
# AVC is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# AVC is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# .-


import gtk				    # gimp tool kit bindings
import gtk.glade			# glade bindings

from avc import *			# AVC

GLADE_XML = 'gtk_colorselection.glade'	# GUI glade descriptor


class Example(AVC):
  """
  Color selection widget connected to label widget (GTK)
  """
  def __init__(self):

    # create GUI
    self.glade = gtk.glade.XML(GLADE_XML)

    # autoconnect GUI signal handlers
    self.glade.signal_autoconnect(self)

    # all types of connected variables
    self.color_value = (0.25,0.50,1.,1.)


  def on_destroy(self,window):
    "Terminate program at window destroy"
    gtk.main_quit()


#### MAIN

example = Example()			# instantiate the application
example.avc_init()			# connect widgets with variables
gtk.main()  			 	# run GTK event loop until quit

#### END



#!/usr/bin/python
# .+
#
# .identifier :	$Id:$
# .context    : Application View Controller
# .title      : A spin button replicated into a label (GTK)
# .kind	      : python source
# .author     : Fabrizio Pollastri
# .site	      : Revello - Italy
# .creation   :	6-Jan-2008
# .copyright  : (c) 2008 Fabrizio Pollastri.
# .license    : GNU General Public License (see below)
#
# This file is part of "AVC, Application View Controller".
#
# AVC is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# AVC is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# .-


import gtk				# gimp tool kit bindings

from avc import *			# AVC


class Example(AVC):
  """
  A spin button whose value is replicated into a label
  """

  def __init__(self):

    ## create GUI
 
    # main window
    window = gtk.Window()
    window.set_title('AVC GTK spin button example')
    window.resize(310,50)
    window.connect('destroy',gtk.main_quit)

    # horizontal layout for widgets inside main window
    hbox = gtk.HBox()
    window.add(hbox)

    # label replicating the spin button value with formatting string
    label = gtk.Label()
    label.set_name('spin_value__label')
    label.set_markup('<b>%d</b>')
    hbox.add(label)

    # spin button
    spinbutton = gtk.SpinButton(gtk.Adjustment(0,0,100,1,5,0))
    spinbutton.set_name('spin_value__spinbutton')
    hbox.add(spinbutton)

    # show all widgets
    window.show_all()


    # the variable holding the spin button value
    self.spin_value = 0


#### MAIN

example = Example()			# instantiate the application
example.avc_init()			# connect widgets with variables
gtk.main()			 	# run GTK event loop until quit

#### END
